package com.gihon.role.controller;
import com.gihon.common.web.response.Response;
import com.gihon.common.web.response.ResponseStatus;
import com.gihon.role.entity.Role;
import com.gihon.role.service.RoleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * @program: 角色控制器
 * @description:
 * @author: dl
 * @create: 02月18日 15时
 **/
@RestController
public class RoleController {
    @Autowired
    private RoleService roleService;
    /**
     * 主要功能：
     * @description 增加角色
     * @author: dl
     * @data 2021/2/20 13:10
     * @param	id	角色id
     * @param	rolename 角色名称
     * @return com.gihon.common.http.Response
     */
    @PreAuthorize("hasAuthority('addRole')")
    @Transactional(rollbackFor = Exception.class)
    @PostMapping(value = "/addRole")
    public Response addRole(Long id, String rolename) {
        Role role = new Role(id, rolename);
        boolean is_save = roleService.save(role);
        return Response.ok();
    }
    /**
     * 主要功能：
     * @description 根据Role ID  删除角色
     * @author: dl
     * @data 2021/2/20 13:18
     * @param	id	 Role ID
     * @return com.gihon.common.http.Response
     */
    public Response 删除角色(Long id){
        boolean is_remove = roleService.removeById(id);
        if (!is_remove) {
            return Response.error(ResponseStatus.MAPPER_ERROR);
        }
        return Response.ok();
    }
    /**
     * 主要功能：
     * @description 根据 id 输入角色名称修改角色
     * @author: dl
     * @data 2021/2/20 13:25
     * @param	id
     * @param	rolename
     * @return com.gihon.common.http.Response
     */
    public Response setRole(long id,String rolename){
        Role role = Role.builder()
                .id(id)
                .name(rolename)
                .build();
        boolean b = roleService.updateById(role);
        if (!b) {
            return Response.error(ResponseStatus.MAPPER_ERROR,"角色数据库访问,修改失败");
        }
        return Response.ok();
    }
    /**
     * 主要功能：
     * @description 根据ID查找角色信息
     * @author: dl
     * @data 2021/2/20 13:27
     * @param	id
     * @return com.gihon.common.http.Response
     */
    public Response findRole(Long id){
        Role role = roleService.getById(id);
        return Response.ok(role);
    }
    /**
     * 主要功能：
     * @description 根据RoleId 查找对应对应权限
     * @author: dl
     * @data 2021/2/20 14:06
     * @param	id
     * @return com.gihon.common.http.Response
     */
    public Response findPermissionByRoleId(Long id){
        Response<List<Role>> permissionsByRoleId = roleService.findPermissionByRoleId(id);
        return permissionsByRoleId;
    }

}
