package com.gihon.user.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gihon.common.web.response.PageBean;
import com.gihon.common.web.response.PageResponse;
import com.gihon.common.web.response.Response;
import com.gihon.common.web.response.ResponseStatus;
import com.gihon.role.entity.Role;
import com.gihon.security.encoder.MyPasswordEncoder;
import com.gihon.user.mapper.UserMapper;
import com.gihon.user.entity.User;
import com.gihon.user.service.UserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
/**
 * @program: common-parent
 * @description:
 * @author: dl
 * @create: 02月20日 09时
 **/
@Service
public class UserServiceImpl extends ServiceImpl<UserMapper,User>  implements UserService {
    @Autowired
    private UserService userService;
    /**
     * 主要功能：
     * @description 根据用户主键查找 用户信息
     * @author: dl
     * @data 2021/2/20 11:43
     * @param	id	 用户信息
     * @return com.gihon.common.http.Response<com.gihon.user.entity.User>
     */
    public Response<User> getUserOne(Long id){
        User user = baseMapper.selectById(id);
        if (user==null){
            return Response.error(ResponseStatus.MAPPER_ERROR,"未查找到此用户");
        }
        return Response.ok();
    }
    /**
     * 主要功能：
     * @description 分页查询用户信息
     * @author: dl
     * @data 2021/2/20 11:38
     * @param    page
     * @param    rows
     * @return com.gihon.common.http.Response<com.gihon.user.entity.User>
     */
    @Override
    public PageResponse<User> getByPage(int page, int rows) {



        //分页配置
        Page<User> itemParamPage = new Page<>(page, rows);
        Page<User> userIPage = (Page<User>) this.page(itemParamPage);

        //PageBean<User> pageBean = new PageBean<User>();
        //BeanUtils.copyProperties(userIPage,pageBean);
        PageBean<User> pageBean = PageBean.createSuccess(
                userIPage.getRecords(),
                userIPage.getTotal(),
                userIPage.getSize(),
                userIPage.getCurrent(),
                userIPage.getPages());
        return PageResponse.ok(pageBean);
    }
    /**
     * 主要功能：
     * @description 根据输入信息增加用户
     * @author: dl
     * @data 2021/2/20 11:39
     * @param	user
     * @return com.gihon.common.http.Response<com.gihon.user.entity.User>
     */
    @Override
    public Response<User> addUser(User user) {
        QueryWrapper<User> wrapper = new QueryWrapper<>(user);
        //不允许增加重复用户
        User user1 = this.getOne(wrapper,false);
        if (user1 != null) {
            return Response.error(ResponseStatus.MAPPER_ERROR,"用户已存在");
        }
        //密码加密
        String passWord = new MyPasswordEncoder().encode(user.getPassword());
        user.setPassword(passWord);
        int i = baseMapper.insert(user);
        //增加失败
        if (i == 0) {
            return Response.error(ResponseStatus.MAPPER_ERROR,"添加用户，访问数据库失败");
        }
        return Response.ok();
    }

    @Override
    public List<String> findPermissionsByUserId(Long id) {
        List<String> strings = baseMapper.selectPermissionsByUserId(id);
        return strings;
    }

    @Override
    public Response addRole4User(User user, Long[] roleIds) {

        User one = this.getOne(new QueryWrapper<>(user), false);
        Long userid = one.getId();


        int i = baseMapper.insertRolestoUser(userid, roleIds);
        if (i!=roleIds.length){
            return Response.error(ResponseStatus.MAPPER_ERROR,"数据未全部增加");
        }
        return Response.ok();
    }

    /**
     * 主要功能：
     * @description 根据主键删除用户
     * @author: dl
     * @data 2021/2/20 11:41
     * @param	id	 用户主键
     * @return com.gihon.common.http.Response<com.gihon.user.entity.User>
     */
    //@PostMapping("/deleteByUserId")
    public Response<User> deleteUser(Long id){
        int i = baseMapper.deleteById(id);
        if (i == 0) {
            return Response.error(ResponseStatus.MAPPER_ERROR,"删除用户，访问数据库失败");
        }
        return Response.ok();
    }
    /**
     * 主要功能：
     * @description 根据
     * 用户id   寻找用户信息
     * 修改用户密码为并输入的密码
     * @author: dl
     * @data 2021/2/20 11:52
     * @param	id
     * @param	password
     * @return com.gihon.common.http.Response<com.gihon.user.entity.User>
     */
    public Response<User> setPasswordByUserId(Long id,String password){
        User user = User.builder()
                .id(id)
                .password(password)
                .build();
        int update = baseMapper.updateById(user);
        if (update == 0) {
            return Response.error(ResponseStatus.MAPPER_ERROR,"数据库 修改此用户失败");
        }
        return Response.ok();
    }
}
