package com.gihon.common.web.response;

import static com.gihon.common.web.response.ResponseStatus.SUCCESS;

import java.util.Collection;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

/**
 * 分页返回数据
 * @author edz
 *{
 *  status:200,
 *  message:success,
 *  data:{
 *  records:[],      --返回内容(集合)
 *  total:100, --总共条数
 *  size:10,    --每页条数
 *  pages:10    --总共页数
 *  current:1    --当前页从1开始
 *  }
 *}
 * @param <T> records元素的类型
 */
public class PageResponse<T> extends Response<PageBean<T>>{


	private PageResponse(int status) {
    	this(status,"",null);
    }

    private PageResponse(int status, String message) {
    	this(status,message,null);
    }

    private PageResponse(int status, PageBean<T> data) {
        this(status, "", data);
    }

    private PageResponse(int status, String message,PageBean<T> data) {
        super(status,message,data);
    }
    
    public static <T> PageResponse<T> ok(Page<T> page) {
        return ok(page.getRecords(),page.getTotal(), page.getCurrent(), page.getSize(), page.getPages());
    }
    
    public static <T> PageResponse<T> ok(PageBean<T> data) {
    	return new PageResponse<T>(SUCCESS.getCode(),SUCCESS.getDesc(), data);
    }

    //用的最多
    public static <T> PageResponse<T> ok(Collection<T> t, long totalCount,long current,long size,long pages) {
        return ok(t, "", totalCount, current, size, pages);
    }

    //分页数据
    public static <T> PageResponse<T> ok(Collection<T> t, String message,long totalCount,long current,long size,long pages) {
        return new PageResponse<T>(SUCCESS.getCode(),message, PageBean.createSuccess(t, totalCount, current, size, pages));
    }
    
    public static <E> PageResponse error(ResponseStatus status,String message) {
    	return new PageResponse<E>(status.getCode(),message,null);
    }
    public static <T> PageResponse error(ResponseStatus status) {
        return error(status,status.getDesc());
    }
     
}
