package com.gihon.common.web.response;


import static com.gihon.common.web.response.ResponseStatus.NO_DATA;
import static com.gihon.common.web.response.ResponseStatus.SUCCESS;
/**
 * 普通的响应值封装
 * @author edz
 *
 * @param <T>
 */
public class Response<T> {

	private int status;
    private String message;
    private T data;
    private Object extInfo;
    
    protected Response() {}

    protected Response(int status) {
        this.status = status;
    }

    protected Response(int status, String message) {
        this.status = status;
        this.message = message;
    }
    protected Response(int status, T data) {
        this.status = status;
        this.data = data;
    }
    protected Response(int status,String message, T data) {
        this.status = status;
        this.data = data;
        this.message = message;
    }
    public static <T> Response<T> ok() {
        return ok(null);
    }
    public static <T> Response<T> ok(T data) {
    	return new Response<T>(SUCCESS.getCode(),SUCCESS.getDesc(), data);
    }
    public static <T> Response<T> noData() {
    	return new Response<T>(NO_DATA.getCode(),NO_DATA.getDesc(), null);
    }
    public static<T> Response<T> error(ResponseStatus status,String message) {
    	return new Response<T>(status.getCode(),message,null);
    }
    public static<T> Response<T> error(ResponseStatus status) {
        return error(status,status.getDesc());
    }
    
	public int getStatus() {
		return status;
	}
	public void setStatus(int status) {
		this.status = status;
	}
	public String getMessage() {
		return message;
	}
	public void setMessage(String message) {
		this.message = message;
	}
	public T getData() {
		return data;
	}
	public void setData(T data) {
		this.data = data;
	}
	public Object getExtInfo() {
		return extInfo;
	}
	public void setExtInfo(Object extInfo) {
		this.extInfo = extInfo;
	}
}
